@@ -14,8 +14,8 @@ from multipletau import autocorrelate, correlate
 
 def test_ac():
     ist = autocorrelate(range(42), m=2, dtype=np.dtype(float))
-
-    soll = np.array([[  1.00000000e+00,   2.29600000e+04],
+    soll = np.array([[  0.00000000e+00,   2.38210000e+04],
+                     [  1.00000000e+00,   2.29600000e+04],
                      [  2.00000000e+00,   2.21000000e+04],
                      [  4.00000000e+00,   2.03775000e+04],
                      [  8.00000000e+00,   1.50612000e+04]])
@@ -23,15 +23,19 @@ def test_ac():
 
 
 def test_cc():
-    soll = correlate(range(42), range(1,43), m=2, dtype=np.dtype(float))
-    ist = np.array([[  1.00000000e+00,   2.38210000e+04],
-                    [  2.00000000e+00,   2.29600000e+04],
-                    [  4.00000000e+00,   2.12325000e+04],
-                    [  8.00000000e+00,   1.58508000e+04]])
+    ist = correlate(range(42), range(1,43), m=2, dtype=np.dtype(float))
+    soll = np.array([[  0.00000000e+00,   2.46820000e+04],
+                     [  1.00000000e+00,   2.38210000e+04],
+                     [  2.00000000e+00,   2.29600000e+04],
+                     [  4.00000000e+00,   2.12325000e+04],
+                     [  8.00000000e+00,   1.58508000e+04]])
     assert np.allclose(soll, ist)
-    
+
     
 if __name__ == "__main__":
-    test_ac()
-    test_cc()
-
+    # Run all tests
+    loc = locals()
+    for key in list(loc.keys()):
+        if key.startswith("test_") and hasattr(loc[key], "__call__"):
+            loc[key]()
+    
\ No newline at end of file
